@@ -437,22 +437,6 @@ public:
     }
   }
 
-  void ClearCell()
-  {
-    gameArea->SetFocusedCellValue(Sudoku::empty);
-  }
-
-  void SetRiddle()
-  {
-    if (gameArea->GetFinishedModel()->Get() ||
-        !gameArea->IsFocusedCellEditable()) {
-      // We ignore possible changes if there is no valid game
-      return;
-    }
-
-    gameArea->SetModel(riddle,solution);
-  }
-
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
   {
     if (model==GetOpenedAction() &&
@@ -502,7 +486,7 @@ public:
       markEmptyAction->Enable();
       solveAction->Enable();
       statAction->Enable();
-      SetRiddle();
+      gameArea->SetModel(riddle,solution);
       gameArea->GetFinishedModel()->On(false);
     }
     else if (model==generateTask.GetAbortedAction() &&
@@ -589,7 +573,7 @@ public:
              clearAction->IsFinished()) {
       if (!lock) {
         lock=true;
-        ClearCell();
+        gameArea->SetFocusedCellValue(Sudoku::empty);
         UpdateKeypad();
         lock=false;
       }
